@@ -3,7 +3,6 @@ from rb.core.lang import Lang
 from rb.core.text_element import TextElement
 from rb.core.sentence import Sentence
 from rb.core.text_element_type import TextElementType
-from rb.core.coref_cluster import CorefCluster
 from typing import List
 
 from rb.utils.rblogger import Logger
@@ -24,16 +23,16 @@ class Block(TextElement):
         for sentence in sentences:
             self.components.append(Sentence(lang, sentence, container=self))
         
-        self.has_coref = False
-        if sentences:
-            try:
-                doc = sentences[0].doc
-                self.has_coref = doc._.has_coref
-                if self.has_coref:
-                    words = {word.index_in_doc: word for sent in self.components for word in sent.components}
-                    self.coref_clusters = [CorefCluster(lang, cluster, words) for cluster in doc._.coref_clusters]
-            except AttributeError:
-                pass
+        # self.has_coref = False
+        # if sentences:
+        #     try:
+        #         doc = sentences[0].doc
+        #         self.has_coref = doc._.has_coref
+        #         if self.has_coref:
+        #             words = {word.index_in_doc: word for sent in self.components for word in sent.components}
+        #             self.coref_clusters = [CorefCluster(lang, cluster, words) for cluster in doc._.coref_clusters]
+        #     except AttributeError:
+        #         pass
 
     def get_sentences(self) -> List[Sentence]:
         return self.components
\ No newline at end of file
